@@ -1,7 +1,6 @@
-use std::path::Path;
-
 use crate::fs::Metadata;
 use crate::io;
+use crate::path::Path;
 use crate::task::blocking;
 
 /// Reads metadata for a path without following symbolic links.
@@ -35,5 +34,5 @@ use crate::task::blocking;
 /// ```
 pub async fn symlink_metadata<P: AsRef<Path>>(path: P) -> io::Result<Metadata> {
     let path = path.as_ref().to_owned();
-    blocking::spawn(async move { std::fs::symlink_metadata(path) }).await
+    blocking::spawn(move || std::fs::symlink_metadata(path)).await
 }
