@@ -1,10 +1,8 @@
-use crate::future::Future;
-use crate::task::{Context, Poll};
-
-use std::io;
 use std::pin::Pin;
 
-use futures_io::AsyncWrite;
+use crate::future::Future;
+use crate::io::{self, Write};
+use crate::task::{Context, Poll};
 
 #[doc(hidden)]
 #[allow(missing_debug_implementations)]
@@ -13,7 +11,7 @@ pub struct WriteFuture<'a, T: Unpin + ?Sized> {
     pub(crate) buf: &'a [u8],
 }
 
-impl<T: AsyncWrite + Unpin + ?Sized> Future for WriteFuture<'_, T> {
+impl<T: Write + Unpin + ?Sized> Future for WriteFuture<'_, T> {
     type Output = io::Result<usize>;
 
     fn poll(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
