@@ -43,12 +43,14 @@
 
 #![cfg_attr(feature = "docs", feature(doc_cfg))]
 #![warn(missing_docs, missing_debug_implementations, rust_2018_idioms)]
+#![allow(clippy::mutex_atomic, clippy::module_inception)]
 #![doc(test(attr(deny(rust_2018_idioms, warnings))))]
 #![doc(test(attr(allow(unused_extern_crates, unused_variables))))]
 #![doc(html_logo_url = "https://async.rs/images/logo--hero.svg")]
-#![recursion_limit = "1024"]
+#![recursion_limit = "2048"]
 
-use cfg_if::cfg_if;
+#[macro_use]
+mod utils;
 
 pub mod fs;
 pub mod future;
@@ -61,26 +63,19 @@ pub mod stream;
 pub mod sync;
 pub mod task;
 
-cfg_if! {
-    if #[cfg(any(feature = "unstable", feature = "docs"))] {
-        #[cfg_attr(feature = "docs", doc(cfg(unstable)))]
-        pub mod pin;
-        #[cfg_attr(feature = "docs", doc(cfg(unstable)))]
-        pub mod process;
+cfg_unstable! {
+    pub mod pin;
+    pub mod process;
 
-        mod unit;
-        mod vec;
-        mod result;
-        mod option;
-        mod string;
-        mod collections;
-    }
+    mod unit;
+    mod vec;
+    mod result;
+    mod option;
+    mod string;
+    mod collections;
+
+    #[doc(inline)]
+    pub use std::{write, writeln};
 }
 
 mod macros;
-pub(crate) mod utils;
-
-#[cfg(any(feature = "unstable", feature = "docs"))]
-#[cfg_attr(feature = "docs", doc(cfg(unstable)))]
-#[doc(inline)]
-pub use std::{write, writeln};
