@@ -3,7 +3,6 @@
 use std::fmt;
 use std::io::{Read as _, Write as _};
 use std::net::Shutdown;
-use std::path::Path;
 use std::pin::Pin;
 
 use mio_uds;
@@ -12,6 +11,7 @@ use super::SocketAddr;
 use crate::io::{self, Read, Write};
 use crate::net::driver::Watcher;
 use crate::os::unix::io::{AsRawFd, FromRawFd, IntoRawFd, RawFd};
+use crate::path::Path;
 use crate::task::{blocking, Context, Poll};
 
 /// A Unix stream socket.
@@ -58,7 +58,7 @@ impl UnixStream {
     pub async fn connect<P: AsRef<Path>>(path: P) -> io::Result<UnixStream> {
         let path = path.as_ref().to_owned();
 
-        blocking::spawn(async move {
+        blocking::spawn(move || {
             let std_stream = std::os::unix::net::UnixStream::connect(path)?;
             let mio_stream = mio_uds::UnixStream::from_stream(std_stream)?;
             Ok(UnixStream {
