@@ -11,8 +11,6 @@
 //! use async_std::prelude::*;
 //! ```
 
-use cfg_if::cfg_if;
-
 #[doc(no_inline)]
 pub use crate::future::Future;
 #[doc(no_inline)]
@@ -41,12 +39,9 @@ pub use crate::io::write::WriteExt as _;
 #[doc(hidden)]
 pub use crate::stream::stream::StreamExt as _;
 
-cfg_if! {
-    if #[cfg(any(feature = "unstable", feature = "docs"))] {
-        #[doc(no_inline)]
-        pub use crate::stream::DoubleEndedStream;
-
-        #[doc(no_inline)]
-        pub use crate::stream::ExactSizeStream;
-    }
+cfg_unstable! {
+    #[doc(no_inline)]
+    pub use crate::stream::DoubleEndedStream;
+    #[doc(no_inline)]
+    pub use crate::stream::ExactSizeStream;
 }
