@@ -1,5 +1,7 @@
 use std::pin::Pin;
 
+use pin_project_lite::pin_project;
+
 use crate::stream::Stream;
 use crate::task::{Context, Poll};
 
@@ -24,20 +26,23 @@ pub fn once<T>(t: T) -> Once<T> {
     Once { value: Some(t) }
 }
 
-/// A stream that yields a single item.
-///
-/// This stream is constructed by the [`once`] function.
-///
-/// [`once`]: fn.once.html
-#[derive(Debug)]
-pub struct Once<T> {
-    value: Option<T>,
+pin_project! {
+    /// A stream that yields a single item.
+    ///
+    /// This stream is created by the [`once`] function. See its
+    /// documentation for more.
+    ///
+    /// [`once`]: fn.once.html
+    #[derive(Debug)]
+    pub struct Once<T> {
+        value: Option<T>,
+    }
 }
 
 impl<T: Unpin> Stream for Once<T> {
     type Item = T;
 
-    fn poll_next(mut self: Pin<&mut Self>, _: &mut Context<'_>) -> Poll<Option<T>> {
-        Poll::Ready(self.value.take())
+    fn poll_next(self: Pin<&mut Self>, _: &mut Context<'_>) -> Poll<Option<T>> {
+        Poll::Ready(self.project().value.take())
     }
 }
