@@ -1,26 +1,29 @@
 use std::cmp::Ordering;
 use std::pin::Pin;
 
+use pin_project_lite::pin_project;
+
 use super::partial_cmp::PartialCmpFuture;
 use crate::future::Future;
 use crate::prelude::*;
 use crate::stream::Stream;
 use crate::task::{Context, Poll};
 
-// Determines if the elements of this `Stream` are lexicographically
-// greater than or equal to those of another.
-#[doc(hidden)]
-#[allow(missing_debug_implementations)]
-pub struct GeFuture<L: Stream, R: Stream> {
-    partial_cmp: PartialCmpFuture<L, R>,
+pin_project! {
+    // Determines if the elements of this `Stream` are lexicographically
+    // greater than or equal to those of another.
+    #[doc(hidden)]
+    #[allow(missing_debug_implementations)]
+    pub struct GeFuture<L: Stream, R: Stream> {
+        #[pin]
+        partial_cmp: PartialCmpFuture<L, R>,
+    }
 }
 
 impl<L: Stream, R: Stream> GeFuture<L, R>
 where
     L::Item: PartialOrd<R::Item>,
 {
-    pin_utils::unsafe_pinned!(partial_cmp: PartialCmpFuture<L, R>);
-
     pub(super) fn new(l: L, r: R) -> Self {
         GeFuture {
             partial_cmp: l.partial_cmp(r),
@@ -30,14 +33,14 @@ where
 
 impl<L: Stream, R: Stream> Future for GeFuture<L, R>
 where
-    L: Stream + Sized,
-    R: Stream + Sized,
+    L: Stream,
+    R: Stream,
     L::Item: PartialOrd<R::Item>,
 {
     type Output = bool;
 
-    fn poll(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
-        let result = futures_core::ready!(self.as_mut().partial_cmp().poll(cx));
+    fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
+        let result = futures_core::ready!(self.project().partial_cmp.poll(cx));
 
         match result {
             Some(Ordering::Greater) | Some(Ordering::Equal) => Poll::Ready(true),
